@@ -3,15 +3,11 @@ use std::process::exit;
 use std::{fs, thread, time::Duration};
 
 use clap::{App, Arg, ArgMatches};
-#[allow(unused_imports)]
-use log::{debug, error, info, trace, warn, LevelFilter, SetLoggerError};
+use log::*;
 use log4rs::append::console::ConsoleAppender;
-use log4rs::append::file::FileAppender;
-use log4rs::config::{Appender, Logger, Root};
+use log4rs::config::{Appender, Root};
 use log4rs::encode::pattern::PatternEncoder;
 use log4rs::Config;
-#[allow(unused_imports)]
-use signal_hook::consts::SIGINT;
 use signal_hook::iterator::Signals;
 use tokio::runtime::Builder;
 use tonic::Request;
@@ -24,12 +20,11 @@ use crate::zymod_config::ZymodConfig;
 mod zhiyan_rpc;
 mod zymod_config;
 
-pub fn string_to_f32_converter(value: String) -> f32 {
-    let change_value = (value)
-        .to_string()
-        .replace("\n", "")
-        .parse::<f32>()
-        .unwrap();
+pub mod floatutils;
+pub mod stringutils;
+
+pub fn string_to_f32_converter(value: &str) -> f32 {
+    let change_value = (value).replace("\n", "").parse::<f32>().unwrap();
     return change_value;
 }
 
@@ -45,27 +40,15 @@ pub fn log_level_converter(log_level: i8) -> LevelFilter {
     }
 }
 
-pub fn build_log_config(
-    log_file_path: String,
-    log_file_level: LevelFilter,
-    log_stdout_level: LevelFilter,
-) -> Config {
-    let stdout = ConsoleAppender::builder().build();
-
-    let requests = FileAppender::builder()
-        .encoder(Box::new(PatternEncoder::new("{d} - {t} -{l} - {m}{n}")))
-        .build(log_file_path.clone())
-        .unwrap();
+pub fn build_log_config(log_stdout_level: LevelFilter) -> Config {
+    let stdout = ConsoleAppender::builder()
+        .encoder(Box::new(PatternEncoder::new(
+            "{d(%Y-%m-%d %H:%M:%S)} - {t} -{l} - {m}{n}",
+        )))
+        .build();
 
     let config = Config::builder()
         .appender(Appender::builder().build("stdout", Box::new(stdout)))
-        .appender(Appender::builder().build("requests", Box::new(requests)))
-        .logger(
-            Logger::builder()
-                .appender("requests")
-                .additive(true)
-                .build("app::requests", log_file_level.clone()),
-        )
         .build(
             Root::builder()
                 .appender("stdout")
@@ -93,14 +76,13 @@ pub fn path_exists(path: &str) -> bool {
     fs::metadata(path).is_ok()
 }
 
-#[derive(Debug)]
 pub struct Zymod {
     mod_conf: ZymodConfig,
 }
 
 impl Zymod {
     pub fn new(
-        mod_conf_path: String,
+        mod_conf_path: &str,
         is_dry_run_from_cmd_args: i32,
         is_verbose_from_cmd_args: i32,
     ) -> Self {
@@ -119,7 +101,7 @@ impl Zymod {
     }
 
     pub fn build_help_parser(
-        prog: String,
+        prog: &str,
         description: &'static str,
         version: &'static str,
         mod_config_file_path: &'static str,
@@ -141,7 +123,7 @@ impl Zymod {
                     .short("n")
                     .long("dry-run")
                     .help("在不做任何更改的情况下试运行，通常和'-v'参数一起使用(1:True,0:False)")
-                    .default_value("1")
+                    .default_value("0")
                     .takes_value(true),
             )
             .arg(
@@ -149,7 +131,7 @@ impl Zymod {
                     .short("v")
                     .long("verbose")
                     .help("显示详细信息(1:True,0:False)")
-                    .default_value("1")
+                    .default_value("0")
                     .takes_value(true),
             )
             .arg(
@@ -165,7 +147,7 @@ impl Zymod {
     }
 
     pub fn build_help(
-        prog: String,
+        prog: &str,
         description: &'static str,
         version: &'static str,
         mod_config_file_path: &'static str,
@@ -186,7 +168,7 @@ impl Zymod {
         return parser.get_matches();
     }
 
-    pub fn upload(self, name: String, datetime: i64, content: String) {
+    pub fn upload(&self, name: &str, datetime: i64, content: String) {
         log::info!("Name:{}", name);
         log::info!("Datetime:{}", datetime);
         log::info!("Content:{}", content);
@@ -207,7 +189,7 @@ impl Zymod {
                 let mut client = ZhiYanClient::connect(agent_address).await.unwrap();
 
                 let request = Request::new(ZhiYanRequest {
-                    name: name.clone(),
+                    name: name.to_string(),
                     datetime: datetime.clone(),
                     content: content.clone(),
                 });
